@@ -3,7 +3,7 @@ use strict;
 use warnings;
 our (%gui, %chooser, %EMedVar);
 
-sub show_vmm_dialog() {
+sub show_dialog_vmm() {
     &addrow_log('Retrieving global media information...');
     &busy_window($gui{windowMain}, 0, 'watch');
     &fill_list_vmmhd();
@@ -64,7 +64,7 @@ sub recurse_media_snapshot() {
                                     2, $gnames,
                                     3, 0,
                                     4, 0,
-                                    5, $gui{pixbufstatuserror16},
+                                    5, $gui{img}{Error},
                                     6, $mattr{accesserr},
                                     7, $mattr{location},
                                     8, $mattr{type});
@@ -86,7 +86,7 @@ sub recurse_media_snapshot() {
                                     1, $IMedium,
                                     2, $gnames,
                                     3, 0,
-                                    4, $gui{pixbufstatuserror16},
+                                    4, $gui{img}{Error},
                                     5, $mattr{accesserr},
                                     6, $mattr{location},
                                     7, $mattr{type});
@@ -107,7 +107,7 @@ sub recurse_media_snapshot() {
                                     1, $IMedium,
                                     2, $gnames,
                                     3, 0,
-                                    4, $gui{pixbufstatuserror16},
+                                    4, $gui{img}{Error},
                                     5, $mattr{accesserr}, # Tooltip can be access error
                                     6, $mattr{location},
                                     7, $mattr{type});
@@ -152,6 +152,7 @@ sub vmm_tabchanged() {
     }
 }
 
+# Releases a medium from a guest
 sub vmm_release() {
     my $mediumref;
     my $page = $gui{notebookVMM}->get_current_page();
@@ -169,14 +170,15 @@ sub vmm_release() {
 
         foreach my $attach (@IMediumAttachment) {
             if ($$attach{medium} eq $$mediumref{IMedium}) {
-                my ($ISession, $IMachineM) = &get_mutable_session($IMachine);
+                my $sref = &get_session($IMachine);
 
-                if ($ISession) {
-                    IMachine_detachDevice($IMachineM, $$attach{controller}, $$attach{port}, $$attach{device});
-                    IMachine_saveSettings($IMachineM);
-                    ISession_unlockMachine($ISession);
+                if ($$sref{Type} eq 'WriteLock') { # Cannot do it if it's a shared lock
+                    IMachine_detachDevice($$sref{IMachine}, $$attach{controller}, $$attach{port}, $$attach{device});
+                    IMachine_saveSettings($$sref{IMachine});
                 }
                 else { $warn = 1; }
+
+                ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
             }
         }
     }
