@@ -3,7 +3,7 @@ use strict;
 use warnings;
 our (%gui, %signal, %bool, %hostspec, %osfamily, %osversion, %EMedVar);
 
-sub show_newguest_dialog() {
+sub show_dialog_newguest() {
     $gui{checkbuttonNewNewHD}->set_active(1);
     $gui{comboboxNewNewFormat}->set_active(0);
     $gui{radiobuttonNewDynamic}->show();
@@ -18,7 +18,11 @@ sub show_newguest_dialog() {
     $gui{liststoreNewOSVer}->clear();
     $gui{liststoreNewChooseHD}->clear();
 
-    foreach my $fam (sort(keys %osfamily)) {
+    foreach my $fam (sort {
+                            if    ($osfamily{$a}{description} =~ m/Other/) { return 1; }
+                            elsif ($osfamily{$b}{description} =~ m/Other/) { return -1; }
+                            else  { return lc($osfamily{$a}{description}) cmp lc($osfamily{$b}{description}) }
+                          } keys %osfamily) {
         my $iter = $gui{liststoreNewOSFam}->append();
         $gui{liststoreNewOSFam}->set($iter, 0, "$osfamily{$fam}{description}", 1, $fam, 2, $osfamily{$fam}{icon});
         $gui{comboboxNewOSFam}->set_active_iter($iter) if ($fam eq 'Windows');
@@ -56,35 +60,46 @@ sub show_newguest_dialog() {
                    ver  => &getsel_combo($gui{comboboxNewOSVer}, 1),
                    mem  => $gui{spinbuttonNewMemory}->get_value_as_int());
 
-        my ($IMachine, $dvdctrname, $hdctrname) = &create_new_guest(\%new);
+        my ($IMachine, $dvdctrname, $hdctrname, $floppyctrname) = &create_new_guest(\%new);
 
         if ($gui{checkbuttonNewNewHD}->get_active() == 1) {
 
             if ($IMachine) {
-                my ($ISession, $IMachineM) = &get_mutable_session($IMachine);
-                my $IMediumHD;
+                my $sref = &get_session($IMachine);
 
-                if ($gui{radiobuttonNewNewHD}->get_active()) {
-                    my %newhd = (diskname   => $new{name}, # Use guest name as basis for disk
-                                 size       => $gui{spinbuttonNewNewHDSize}->get_value_as_int() * 1048576,
-                                 allocation => $EMedVar{Standard}, # Standard == Dynamic Allocation
-                                 imgformat  => &getsel_combo($gui{comboboxNewNewFormat}, 1),
-                                 location   => "$hostspec{machinedir}/$new{name}");
+                if ($$sref{Type} eq 'WriteLock') {
+                    my $IMediumHD;
 
-                    if ($gui{radiobuttonNewFixed}->get_active()) { $newhd{allocation} = $EMedVar{Fixed}; }
-                    elsif ($gui{radiobuttonNewSplit}->get_active()) { $newhd{allocation} = $EMedVar{VmdkSplit2G}; }
-                    $IMediumHD = &create_new_hd(\%newhd, $gui{windowMain});
+                    if ($gui{radiobuttonNewNewHD}->get_active()) {
+                        my %newhd = (diskname   => $new{name}, # Use guest name as basis for disk
+                                     size       => $gui{spinbuttonNewNewHDSize}->get_value_as_int() * 1048576,
+                                     allocation => $EMedVar{Standard}, # Standard == Dynamic Allocation
+                                     imgformat  => &getsel_combo($gui{comboboxNewNewFormat}, 1),
+                                     location   => "$hostspec{machinedir}/$new{name}");
+
+                        if ($gui{radiobuttonNewFixed}->get_active()) { $newhd{allocation} = $EMedVar{Fixed}; }
+                        elsif ($gui{radiobuttonNewSplit}->get_active()) { $newhd{allocation} = $EMedVar{VmdkSplit2G}; }
+                        $IMediumHD = &create_new_hd(\%newhd, $gui{windowMain});
+                    }
+                    else { $IMediumHD = &getsel_combo($gui{comboboxNewChooseHD}, 1); }
+
+                    my $IStorCtrHD = IMachine_getStorageControllerByName($$sref{IMachine}, $hdctrname);
+                    my %hdaddress = &get_free_deviceport($$sref{IMachine}, $IStorCtrHD);
+                    IMachine_attachDevice($$sref{IMachine}, $hdctrname, $hdaddress{portnum}, $hdaddress{devnum}, 'HardDisk', $IMediumHD);
+                    my $IStorCtrDVD = IMachine_getStorageControllerByName($$sref{IMachine}, $dvdctrname); # Attach Empty CD/DVD Device
+                    my %dvdaddress = &get_free_deviceport($$sref{IMachine}, $IStorCtrDVD);
+                    IMachine_attachDevice($$sref{IMachine}, $dvdctrname, $dvdaddress{portnum}, $dvdaddress{devnum}, 'DVD', '');
+
+                    if ($floppyctrname) {
+                        my $IStorCtrFloppy = IMachine_getStorageControllerByName($$sref{IMachine}, $floppyctrname);
+                        my %floppyaddress = &get_free_deviceport($$sref{IMachine}, $IStorCtrFloppy);
+                        IMachine_attachDevice($$sref{IMachine}, $floppyctrname, $floppyaddress{portnum}, $floppyaddress{devnum}, 'Floppy', '');
+                    }
+
+                    IMachine_saveSettings($$sref{IMachine});
                 }
-                else { $IMediumHD = &getsel_combo($gui{comboboxNewChooseHD}, 1); }
 
-                my $IStorCtrHD = IMachine_getStorageControllerByName($IMachineM, $hdctrname);
-                my %hdaddress = &get_free_deviceport($IMachineM, $IStorCtrHD);
-                IMachine_attachDevice($IMachineM, $hdctrname, $hdaddress{portnum}, $hdaddress{devnum}, 'HardDisk', $IMediumHD);
-                my $IStorCtrDVD = IMachine_getStorageControllerByName($IMachineM, $dvdctrname); # Attach Empty CD/DVD Device
-                my %dvdaddress = &get_free_deviceport($IMachineM, $IStorCtrDVD);
-                IMachine_attachDevice($IMachineM, $dvdctrname, $dvdaddress{portnum}, $dvdaddress{devnum}, 'DVD', '');
-                IMachine_saveSettings($IMachineM);
-                ISession_unlockMachine($ISession);
+                ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
             }
             else { &show_err_msg('createguest', $gui{messagedialogError}, " ($new{name})"); }
         }
@@ -92,13 +107,12 @@ sub show_newguest_dialog() {
     }
 }
 
-
 # We have some serious limitations as the moment when setting the clone
 # options. The vboxservice.pm doesn't seem to be able to handle the
 # passing of arrays which means when creating a clone we can only set
 # one option at creatiom. Ie we can't have Linked and KeepALLMACs set.
 # Need to find a work around.
-sub show_clone_dialog() {
+sub show_dialog_clone() {
     my $gref = &getsel_list_guest();
     $gui{entryCloneName}->set_text($$gref{Name} . ' Clone' . int(rand(9999)));
     $gui{comboboxCloneType}->set_active(0);
@@ -169,7 +183,7 @@ sub create_new_clone() {
     my ($srcgref, $clonename, $clonetype, $newmacs) = @_;
 
     # We create a new 'empty' guest
-    my $cloneIMachine = IVirtualBox_createMachine($gui{websn}, '', $clonename, $$srcgref{Osid}, 'UUID 00000000-0000-0000-0000-000000000000', '');
+    my $cloneIMachine = IVirtualBox_createMachine($gui{websn}, '', $clonename, '', $$srcgref{Osid}, 'UUID 00000000-0000-0000-0000-000000000000', '');
     my $IProgress;
 
     if ($clonetype eq 'Link') {
@@ -200,47 +214,53 @@ sub create_new_clone() {
     &addrow_log("Cloned $$srcgref{Name} to $clonename");
 }
 
+# Creates a new guest
 sub create_new_guest() {
     my ($newref) = @_;
     my %os = %{ $osversion{$$newref{ver}} };
-    my $dvdctrname = $os{recommendedDvdStorageBus} .  ' Controller';
-    my $hdctrname = $os{recommendedHdStorageBus} . ' Controller';
+    my $dvdctrname = $os{recommendedDVDStorageBus} .  ' Controller';
+    my $hdctrname = $os{recommendedHDStorageBus} . ' Controller';
+    my $floppyctrname = 'Floppy Controller' if ($os{recommendedFloppy} eq 'true');
     my $portnum = int(rand(15000)) + 50000; # Pick random between 50000 and 65000
-    my $IMachine = IVirtualBox_createMachine($gui{websn}, '', $$newref{name}, $$newref{ver}, 'UUID 00000000-0000-0000-0000-000000000000', '');
+    my $IMachine = IVirtualBox_createMachine($gui{websn}, '', $$newref{name}, '', $$newref{ver}, 'UUID 00000000-0000-0000-0000-000000000000', '');
 
     if ($IMachine) {
         my $IVRDEServer = IMachine_getVRDEServer($IMachine);
         my $IBIOSSettings = IMachine_getBIOSSettings($IMachine);
         my $IAudioAdapter = IMachine_getAudioAdapter($IMachine);
+        my $IUSBController = IMachine_getUSBController($IMachine);
+        IMachine_setChipsetType($IMachine, $os{recommendedChipset});
         IBIOSSettings_setIOAPICEnabled($IBIOSSettings, $bool{$os{recommendedIOAPIC}});
-        IMachine_setCPUProperty($IMachine, 'PAE', $bool{$os{recommendedPae}});
+        IMachine_setCPUProperty($IMachine, 'PAE', $bool{$os{recommendedPAE}});
         IMachine_setHWVirtExProperty($IMachine, 'Enabled', 1);
-        IMachine_setHpetEnabled($IMachine, $bool{$os{recommendedHpet}});
+        IMachine_setHPETEnabled($IMachine, $bool{$os{recommendedHPET}});
         IMachine_setVRAMSize($IMachine, $os{recommendedVRAM});
         IMachine_setFirmwareType($IMachine, $os{recommendedFirmware});
         IMachine_setMemorySize($IMachine, $$newref{mem});
-        IMachine_setRTCUseUTC($IMachine, $bool{$os{recommendedRtcUseUtc}});
+        IMachine_setRTCUseUTC($IMachine, $bool{$os{recommendedRTCUseUTC}});
+        IAudioAdapter_setAudioController($IAudioAdapter, $os{recommendedAudioController});
         IAudioAdapter_setAudioDriver($IAudioAdapter, 'Null');
+        IAudioAdapter_setEnabled($IAudioAdapter, 1);
+        IUSBController_setEnabled($IUSBController, $bool{$os{recommendedUSB}});
 
-        if ($os{recommendedUsbHid} eq 'true') {
-            my $IUSBController = IMachine_getUSBController($IMachine);
+        if ($os{recommendedUSBHID} eq 'true') {
             IUSBController_setEnabled($IUSBController, 1);
-            IMachine_setPointingHidType($IMachine, 'USBMouse');
+            IMachine_setPointingHIDType($IMachine, 'USBMouse');
         }
 
-        if ($os{recommendedUsbTablet} eq 'true') {
-            my $IUSBController = IMachine_getUSBController($IMachine);
+        if ($os{recommendedUSBTablet} eq 'true') {
             IUSBController_setEnabled($IUSBController, 1);
-            IMachine_setPointingHidType($IMachine, 'USBTablet');
+            IMachine_setPointingHIDType($IMachine, 'USBTablet');
         }
 
-        my $IStorCtrDVD = IMachine_addStorageController($IMachine, $dvdctrname, $os{recommendedDvdStorageBus});
-        IStorageController_setControllerType($IStorCtrDVD, $os{recommendedDvdStorageController});
+        my $IStorCtrFloppy = IMachine_addStorageController($IMachine, $floppyctrname, 'Floppy') if ($floppyctrname);
+        my $IStorCtrDVD = IMachine_addStorageController($IMachine, $dvdctrname, $os{recommendedDVDStorageBus});
+        IStorageController_setControllerType($IStorCtrDVD, $os{recommendedDVDStorageController});
         IStorageController_setPortCount($IStorCtrDVD, IStorageController_getMinPortCount($IStorCtrDVD)); # Controllers have all ports on by default. Set to the minimum
 
-        if ($os{recommendedHdStorageBus} ne $os{recommendedDvdStorageBus}) {
-            my $IStorCtrHD = IMachine_addStorageController($IMachine, $hdctrname, $os{recommendedHdStorageBus});
-            IStorageController_setControllerType($IStorCtrHD, $os{recommendedHdStorageController});
+        if ($os{recommendedHDStorageBus} ne $os{recommendedDVDStorageBus}) {
+            my $IStorCtrHD = IMachine_addStorageController($IMachine, $hdctrname, $os{recommendedHDStorageBus});
+            IStorageController_setControllerType($IStorCtrHD, $os{recommendedHDStorageController});
             IStorageController_setPortCount($IStorCtrHD, IStorageController_getMinPortCount($IStorCtrHD)); # Controllers have all ports on by default. Set to the minimum
         }
 
@@ -258,7 +278,7 @@ sub create_new_guest() {
         &addrow_log("Created a new guest: $$newref{name}.");
     }
 
-    return $IMachine, $dvdctrname, $hdctrname;
+    return $IMachine, $dvdctrname, $hdctrname, $floppyctrname;
 }
 
 # Creates a new hard disk and shows a progress window
@@ -281,7 +301,12 @@ sub newgen_osfam() {
     $combover->signal_handler_block($signal{ver});
     $gui{liststoreNewOSVer}->clear();
 
-    foreach my $ver (sort(@{ $osfamily{$fam}{verids} })) {
+    foreach my $ver (sort {
+                            if    ($osversion{$a}{description} =~ m/Other/) { return 1; }
+                            elsif ($osversion{$b}{description} =~ m/Other/) { return -1; }
+                            else  { return lc($osversion{$a}{description}) cmp lc($osversion{$b}{description}) }
+                          } (@{ $osfamily{$fam}{verids} }))
+    {
         my $iter = $gui{liststoreNewOSVer}->append();
         $gui{liststoreNewOSVer}->set($iter, 0, $osversion{$ver}{description}, 1, $ver, 2, $osversion{$ver}{icon});
         $combover->set_active_iter($iter) if ($ver eq 'WindowsXP' | $ver eq 'Ubuntu' | $ver eq 'Solaris');
