@@ -20,6 +20,12 @@ sub SOAP::Serializer::as_AdditionsRunLevelType {
     return [$name, {'xsi:type' => 'vbox:AdditionsRunLevelType', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_AdditionsUpdateFlag {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:AdditionsUpdateFlag', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_AudioControllerType {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -38,6 +44,12 @@ sub SOAP::Serializer::as_AuthType {
     return [$name, {'xsi:type' => 'vbox:AuthType', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_AutostopType {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:AutostopType', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_BIOSBootMenuMode {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -86,18 +98,60 @@ sub SOAP::Serializer::as_CloneOptions {
     return [$name, {'xsi:type' => 'vbox:CloneOptions', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_CopyFileFlag {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:CopyFileFlag', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_DeviceType {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
     return [$name, {'xsi:type' => 'vbox:DeviceType', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_DirectoryCreateFlag {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:DirectoryCreateFlag', %$attr}, $value];
+}
+
+sub SOAP::Serializer::as_DirectoryOpenFlag {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:DirectoryOpenFlag', %$attr}, $value];
+}
+
+sub SOAP::Serializer::as_DirectoryRemoveRecFlag {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:DirectoryRemoveRecFlag', %$attr}, $value];
+}
+
+sub SOAP::Serializer::as_DragAndDropAction {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:DragAndDropAction', %$attr}, $value];
+}
+
+sub SOAP::Serializer::as_DragAndDropMode {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:DragAndDropMode', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_FaultToleranceState {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
     return [$name, {'xsi:type' => 'vbox:FaultToleranceState', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_FileSeekType {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:FileSeekType', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_FirmwareType {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -122,10 +176,10 @@ sub SOAP::Serializer::as_ImportOptions {
     return [$name, {'xsi:type' => 'vbox:ImportOptions', %$attr}, $value];
 }
 
-sub SOAP::Serializer::as_KeyboardHidType {
+sub SOAP::Serializer::as_KeyboardHIDType {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
-    return [$name, {'xsi:type' => 'vbox:KeyboardHidType', %$attr}, $value];
+    return [$name, {'xsi:type' => 'vbox:KeyboardHIDType', %$attr}, $value];
 }
 
 sub SOAP::Serializer::as_LockType {
@@ -164,10 +218,16 @@ sub SOAP::Serializer::as_NetworkAttachmentType {
     return [$name, {'xsi:type' => 'vbox:NetworkAttachmentType', %$attr}, $value];
 }
 
-sub SOAP::Serializer::as_PointingHidType {
+sub SOAP::Serializer::as_PathRenameFlag {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
-    return [$name, {'xsi:type' => 'vbox:PointingHidType', %$attr}, $value];
+    return [$name, {'xsi:type' => 'vbox:PathRenameFlag', %$attr}, $value];
+}
+
+sub SOAP::Serializer::as_PointingHIDType {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:PointingHIDType', %$attr}, $value];
 }
 
 sub SOAP::Serializer::as_PortMode {
@@ -176,6 +236,30 @@ sub SOAP::Serializer::as_PortMode {
     return [$name, {'xsi:type' => 'vbox:PortMode', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_ProcessCreateFlag {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:ProcessCreateFlag', %$attr}, $value];
+}
+
+sub SOAP::Serializer::as_ProcessInputFlag {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:ProcessInputFlag', %$attr}, $value];
+}
+
+sub SOAP::Serializer::as_ProcessPriority {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:ProcessPriority', %$attr}, $value];
+}
+
+sub SOAP::Serializer::as_ProcessWaitForFlag {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:ProcessWaitForFlag', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_ProcessorFeature {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -194,6 +278,18 @@ sub SOAP::Serializer::as_StorageControllerType {
     return [$name, {'xsi:type' => 'vbox:StorageControllerType', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_SymlinkReadFlag {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:SymlinkReadFlag', %$attr}, $value];
+}
+
+sub SOAP::Serializer::as_SymlinkType {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:SymlinkType', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_USBDeviceFilterAction {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
